#define	dosbox_ico	102
#define	ID_OPENFILE	103
#define	ID_KEYMAP	104
#define	ID_DOSBOX_SECTION	105
#define	ID_CAPMOUSE	106
#define	ID_PAUSE	107
#define	ID_SURFACE	108
#define	ID_OPENGL	110
#define	ID_OPENGLNB	111
#define	ID_DIRECT3D	113
#define	ID_D3D_PS	114
#define	ID_TOGGLE	115
#define	ID_HIDECYCL	116
#define	ID_REFRESH	117
#define	ID_QUIT	118
#define	ID_AUTOCYCLE	119
#define	ID_AUTODETER	120
#define	ID_NORMAL	121
#define	ID_DYNAMIC	122
#define	ID_FULL	123
#define	ID_SIMPLE	124
#define	ID_AUTO	125
#define	ID_CPUTYPE_AUTO	126
#define	ID_CPUTYPE_386	127
#define	ID_CPUTYPE_386_PREFETCH	128
#define	ID_CPUTYPE_486	129
#define	ID_CPUTYPE_PENTIUM	130
#define	ID_FULLSCREEN	131
#define	ID_ASPECT	132
#define	ID_NONE	133
#define	ID_ADVMAME2X	134
#define	ID_ADVMAME3X	135
#define	ID_HQ2X	136
#define	ID_HQ3X	137
#define	ID_ADVINTERP2X	138
#define	ID_ADVINTERP3X	139
#define	ID_TV2X	140
#define	ID_TV3X	141
#define	ID_SCAN2X	142
#define	ID_SCAN3X	143
#define	ID_RGB2X	144
#define	ID_RGB3X	145
#define	ID_NORMAL2X	146
#define	ID_NORMAL3X	147
#define	ID_HARDWARE2X	148
#define	ID_HARDWARE3X	149
#define	ID_2XSAI	150
#define	ID_SUPER2XSAI	151
#define	ID_SUPEREAGLE	152
#define	ID_VSYNC_ON	153
#define	ID_VSYNC_OFF	154
#define	ID_VSYNC_FORCE	155
#define	ID_VSYNC	156
#define	ID_MIXER_SECTION	157
#define	ID_SB_NONE	158
#define	ID_SB_SB1	159
#define	ID_SB_SB2	160
#define	ID_SB_SBPRO1	161
#define	ID_SB_SBPRO2	162
#define	ID_SB_SB16	163
#define	ID_SB_GB	164
#define	ID_SB_220	165
#define	ID_SB_240	166
#define	ID_SB_260	167
#define	ID_SB_280	168
#define	ID_SB_2a0	169
#define	ID_SB_2c0	170
#define	ID_SB_2e0	171
#define	ID_SB_300	172
#define	ID_SB_IRQ_3	173
#define	ID_SB_IRQ_5	174
#define	ID_SB_IRQ_7	175
#define	ID_SB_IRQ_9	176
#define	ID_SB_IRQ_10	177
#define	ID_SB_IRQ_11	178
#define	ID_SB_IRQ_12	179
#define	ID_SB_DMA_0	180
#define	ID_SB_DMA_1	181
#define	ID_SB_DMA_3	182
#define	ID_SB_DMA_5	183
#define	ID_SB_DMA_6	184
#define	ID_SB_DMA_7	185
#define	ID_SB_HDMA_0	186
#define	ID_SB_HDMA_1	187
#define	ID_SB_HDMA_3	188
#define	ID_SB_HDMA_5	189
#define	ID_SB_HDMA_6	190
#define	ID_SB_HDMA_7	191
#define	ID_SB_OPL_NONE	192
#define	ID_SB_OPL_AUTO	193
#define	ID_SB_OPL_CMS	194
#define	ID_SB_OPL_OPL2	195
#define	ID_SB_OPL_DUALOPL2	196
#define	ID_SB_OPL_OPL3	197
#define	ID_SB_OPL_49716	198
#define	ID_SB_OPL_48000	199
#define	ID_SB_OPL_44100	200
#define	ID_SB_OPL_32000	201
#define	ID_SB_OPL_22050	202
#define	ID_SB_OPL_16000	203
#define	ID_SB_OPL_11025	204
#define	ID_SB_OPL_8000	205
#define	ID_SB_OPL_EMU_DEFAULT	206
#define	ID_SB_OPL_EMU_COMPAT	207
#define	ID_SB_OPL_EMU_FAST	208
#define	ID_GUS_TRUE	209
#define	ID_GUS_FALSE	210
#define	ID_GUS_44100	211
#define	ID_GUS_48000	212
#define	ID_GUS_32000	213
#define	ID_GUS_22050	214
#define	ID_GUS_16000	215
#define	ID_GUS_11025	216
#define	ID_GUS_8000	217
#define	ID_GUS_49716	218
#define	ID_GUS_240	219
#define	ID_GUS_220	220
#define	ID_GUS_260	221
#define	ID_GUS_280	222
#define	ID_GUS_2a0	223
#define	ID_GUS_2c0	224
#define	ID_GUS_2e0	225
#define	ID_GUS_300	226
#define	ID_GUS_IRQ_5	227
#define	ID_GUS_IRQ_3	228
#define	ID_GUS_IRQ_7	229
#define	ID_GUS_IRQ_9	230
#define	ID_GUS_IRQ_10	231
#define	ID_GUS_IRQ_11	232
#define	ID_GUS_IRQ_12	233
#define	ID_GUS_DMA_0	234
#define	ID_GUS_DMA_3	235
#define	ID_GUS_DMA_1	236
#define	ID_GUS_DMA_5	237
#define	ID_GUS_DMA_6	238
#define	ID_GUS_DMA_7	239
#define	ID_PCSPEAKER_TRUE	240
#define	ID_PCSPEAKER_FALSE	241
#define	ID_PCSPEAKER_49716	242
#define	ID_PCSPEAKER_48000	243
#define	ID_PCSPEAKER_44100	244
#define	ID_PCSPEAKER_32000	245
#define	ID_PCSPEAKER_22050	246
#define	ID_PCSPEAKER_16000	247
#define	ID_PCSPEAKER_11025	248
#define	ID_PCSPEAKER_8000	249
#define	ID_TANDY_ON	250
#define	ID_TANDY_OFF	251
#define	ID_TANDY_AUTO	252
#define	ID_TANDY_49716	253
#define	ID_TANDY_48000	254
#define	ID_TANDY_44100	255
#define	ID_TANDY_32000	256
#define	ID_TANDY_22050	257
#define	ID_TANDY_16000	258
#define	ID_TANDY_11025	259
#define	ID_TANDY_8000	260
#define	ID_MIDI_NONE	261
#define	ID_MIDI_UART	262
#define	ID_MIDI_INTELLI	263
#define	ID_MIDI_DEFAULT	264
#define	ID_MIDI_ALSA	265
#define	ID_MIDI_OSS	266
#define	ID_MIDI_WIN32	267
#define	ID_MIDI_COREAUDIO	268
#define	ID_MIDI_COREMIDI	269
#define	ID_MIDI_MT32	270
#define	ID_MIDI_DEV_NONE	271
#define	ID_DISNEY_TRUE	272
#define	ID_DISNEY_FALSE	273
#define	ID_INNOVA_TRUE	274
#define	ID_INNOVA_FALSE	275
#define	ID_INNOVA_220	276
#define	ID_INNOVA_240	277
#define	ID_INNOVA_260	278
#define	ID_INNOVA_300	279
#define	ID_INNOVA_49716	280
#define	ID_INNOVA_48000	281
#define	ID_INNOVA_44100	282
#define	ID_INNOVA_32000	283
#define	ID_INNOVA_22050	284
#define	ID_INNOVA_11025	285
#define	ID_INNOVA_16000	286
#define	ID_INNOVA_8000	287
#define	ID_INNOVA_280	288
#define	ID_INNOVA_2A0	289
#define	ID_INNOVA_2C0	290
#define	ID_INNOVA_2E0	291
#define	ID_INNOVA_3	292
#define	ID_INNOVA_2	293
#define	ID_INNOVA_1	294
#define	ID_INNOVA_0	295
#define	ID_CYCLE	296
#define	ID_XMS	297
#define	ID_EMS_TRUE	298
#define	ID_EMS_FALSE	299
#define	ID_EMS_EMM386	300
#define	ID_EMS_EMSBOARD	301
#define	ID_UMB	302
#define	ID_IPXNET	303
#define	ID_SSHOT	304
#define	ID_MOVIE	305
#define	ID_WAVE	306
#define	ID_OPL	307
#define	ID_MIDI	308
#define	ID_UMOUNT_A	309
#define	ID_UMOUNT_B	310
#define	ID_UMOUNT_C	311
#define	ID_UMOUNT_D	312
#define	ID_UMOUNT_E	313
#define	ID_UMOUNT_F	314
#define	ID_UMOUNT_G	315
#define	ID_UMOUNT_H	316
#define	ID_UMOUNT_I	317
#define	ID_UMOUNT_J	318
#define	ID_UMOUNT_K	319
#define	ID_UMOUNT_L	320
#define	ID_UMOUNT_M	321
#define	ID_UMOUNT_N	322
#define	ID_UMOUNT_O	323
#define	ID_UMOUNT_P	324
#define	ID_UMOUNT_Q	325
#define	ID_UMOUNT_R	326
#define	ID_UMOUNT_S	327
#define	ID_UMOUNT_T	328
#define	ID_UMOUNT_U	329
#define	ID_UMOUNT_V	330
#define	ID_UMOUNT_W	331
#define	ID_UMOUNT_X	332
#define	ID_UMOUNT_Y	333
#define	ID_UMOUNT_Z	334
#define	ID_AUTOMOUNT_A	335
#define	ID_AUTOMOUNT_B	336
#define	ID_AUTOMOUNT_C	337
#define	ID_AUTOMOUNT_D	338
#define	ID_AUTOMOUNT_E	339
#define	ID_AUTOMOUNT_F	340
#define	ID_AUTOMOUNT_G	341
#define	ID_AUTOMOUNT_H	342
#define	ID_AUTOMOUNT_I	343
#define	ID_AUTOMOUNT_J	344
#define	ID_AUTOMOUNT_K	345
#define	ID_AUTOMOUNT_L	346
#define	ID_AUTOMOUNT_M	347
#define	ID_AUTOMOUNT_N	348
#define	ID_AUTOMOUNT_O	349
#define	ID_AUTOMOUNT_P	350
#define	ID_AUTOMOUNT_Q	351
#define	ID_AUTOMOUNT_R	352
#define	ID_AUTOMOUNT_S	353
#define	ID_AUTOMOUNT_T	354
#define	ID_AUTOMOUNT_U	355
#define	ID_AUTOMOUNT_V	356
#define	ID_AUTOMOUNT_W	357
#define	ID_AUTOMOUNT_X	358
#define	ID_AUTOMOUNT_Y	359
#define	ID_MOUNT_CDROM_A	360
#define	ID_MOUNT_CDROM_B	361
#define	ID_MOUNT_CDROM_C	362
#define	ID_MOUNT_CDROM_D	363
#define	ID_MOUNT_CDROM_E	364
#define	ID_MOUNT_CDROM_F	365
#define	ID_MOUNT_CDROM_G	366
#define	ID_MOUNT_CDROM_H	367
#define	ID_MOUNT_CDROM_I	368
#define	ID_MOUNT_CDROM_J	369
#define	ID_MOUNT_CDROM_K	370
#define	ID_MOUNT_CDROM_L	371
#define	ID_MOUNT_CDROM_M	372
#define	ID_MOUNT_CDROM_N	373
#define	ID_MOUNT_CDROM_O	374
#define	ID_MOUNT_CDROM_P	375
#define	ID_MOUNT_CDROM_Q	376
#define	ID_MOUNT_CDROM_R	377
#define	ID_MOUNT_CDROM_S	378
#define	ID_MOUNT_CDROM_T	379
#define	ID_MOUNT_CDROM_U	380
#define	ID_MOUNT_CDROM_V	381
#define	ID_MOUNT_CDROM_W	382
#define	ID_MOUNT_CDROM_X	383
#define	ID_MOUNT_CDROM_Y	384
#define	ID_MOUNT_FLOPPY_A	385
#define	ID_MOUNT_FLOPPY_B	386
#define	ID_MOUNT_FLOPPY_C	387
#define	ID_MOUNT_FLOPPY_D	388
#define	ID_MOUNT_FLOPPY_E	389
#define	ID_MOUNT_FLOPPY_F	390
#define	ID_MOUNT_FLOPPY_G	391
#define	ID_MOUNT_FLOPPY_H	392
#define	ID_MOUNT_FLOPPY_I	393
#define	ID_MOUNT_FLOPPY_J	394
#define	ID_MOUNT_FLOPPY_K	395
#define	ID_MOUNT_FLOPPY_L	396
#define	ID_MOUNT_FLOPPY_M	397
#define	ID_MOUNT_FLOPPY_N	398
#define	ID_MOUNT_FLOPPY_O	399
#define	ID_MOUNT_FLOPPY_P	400
#define	ID_MOUNT_FLOPPY_Q	401
#define	ID_MOUNT_FLOPPY_R	402
#define	ID_MOUNT_FLOPPY_S	403
#define	ID_MOUNT_FLOPPY_T	404
#define	ID_MOUNT_FLOPPY_U	405
#define	ID_MOUNT_FLOPPY_V	406
#define	ID_MOUNT_FLOPPY_W	407
#define	ID_MOUNT_FLOPPY_X	408
#define	ID_MOUNT_FLOPPY_Y	409
#define	ID_MOUNT_LOCAL_A	410
#define	ID_MOUNT_LOCAL_B	411
#define	ID_MOUNT_LOCAL_C	412
#define	ID_MOUNT_LOCAL_D	413
#define	ID_MOUNT_LOCAL_E	414
#define	ID_MOUNT_LOCAL_F	415
#define	ID_MOUNT_LOCAL_G	416
#define	ID_MOUNT_LOCAL_H	417
#define	ID_MOUNT_LOCAL_I	418
#define	ID_MOUNT_LOCAL_J	419
#define	ID_MOUNT_LOCAL_K	420
#define	ID_MOUNT_LOCAL_L	421
#define	ID_MOUNT_LOCAL_M	422
#define	ID_MOUNT_LOCAL_N	423
#define	ID_MOUNT_LOCAL_O	424
#define	ID_MOUNT_LOCAL_P	425
#define	ID_MOUNT_LOCAL_Q	426
#define	ID_MOUNT_LOCAL_R	427
#define	ID_MOUNT_LOCAL_S	428
#define	ID_MOUNT_LOCAL_T	429
#define	ID_MOUNT_LOCAL_U	430
#define	ID_MOUNT_LOCAL_V	431
#define	ID_MOUNT_LOCAL_W	432
#define	ID_MOUNT_LOCAL_X	433
#define	ID_MOUNT_LOCAL_Y	434
#define	ID_MOUNT_IMAGE_A	435
#define	ID_MOUNT_IMAGE_B	436
#define	ID_MOUNT_IMAGE_C	437
#define	ID_MOUNT_IMAGE_D	438
#define	ID_MOUNT_IMAGE_E	439
#define	ID_MOUNT_IMAGE_F	440
#define	ID_MOUNT_IMAGE_G	441
#define	ID_MOUNT_IMAGE_H	442
#define	ID_MOUNT_IMAGE_I	443
#define	ID_MOUNT_IMAGE_J	444
#define	ID_MOUNT_IMAGE_K	445
#define	ID_MOUNT_IMAGE_L	446
#define	ID_MOUNT_IMAGE_M	447
#define	ID_MOUNT_IMAGE_N	448
#define	ID_MOUNT_IMAGE_O	449
#define	ID_MOUNT_IMAGE_P	450
#define	ID_MOUNT_IMAGE_Q	451
#define	ID_MOUNT_IMAGE_R	452
#define	ID_MOUNT_IMAGE_S	453
#define	ID_MOUNT_IMAGE_T	454
#define	ID_MOUNT_IMAGE_U	455
#define	ID_MOUNT_IMAGE_V	456
#define	ID_MOUNT_IMAGE_W	457
#define	ID_MOUNT_IMAGE_X	458
#define	ID_MOUNT_IMAGE_Y	459
#define	ID_FORCESCALER	460
#define	ID_VSYNC_HOST	461
#define	ID_WINRES_USER	463
#define	ID_WINRES_DESKTOP	464
#define	ID_WINFULL_USER	465
#define	ID_WINFULL_DESKTOP	466
#define	ID_WINRES_ORIGINAL	467
#define	ID_WINFULL_ORIGINAL	468
#define	ID_KEY_NONE	469
#define	ID_KEY_BG	470
#define	ID_KEY_CZ	471
#define	ID_KEY_FR	472
#define	ID_KEY_GK	473
#define	ID_KEY_GR	474
#define	ID_KEY_HR	475
#define	ID_KEY_HU	476
#define	ID_KEY_SV	477
#define	ID_KEY_IT	478
#define	ID_KEY_NL	479
#define	ID_KEY_NO	480
#define	ID_KEY_PL	481
#define	ID_KEY_RU	482
#define	ID_KEY_SK	483
#define	ID_KEY_SP	484
#define	ID_KEY_SU	485
#define	ID_FULLDOUBLE	486
#define	ID_AUTOLOCK	487
#define	ID_MOUSE	488
#define	ID_JOYSTICKTYPE_AUTO	489
#define	ID_JOYSTICKTYPE_2AXIS	490
#define	ID_JOYSTICKTYPE_4AXIS	491
#define	ID_JOYSTICKTYPE_4AXIS_2	492
#define	ID_JOYSTICKTYPE_FCS	493
#define	ID_JOYSTICKTYPE_CH	494
#define	ID_JOYSTICKTYPE_NONE	495
#define	ID_JOYSTICK_TIMED	496
#define	ID_JOYSTICK_AUTOFIRE	497
#define	ID_JOYSTICK_SWAP34	498
#define	ID_JOYSTICK_BUTTONWRAP	499
#define	ID_SERIAL_SECTION	500
#define	ID_PARALLEL_SECTION	501
#define	ID_NE2000_SECTION	502
#define	ID_BOOT_A	503
#define	ID_BOOT_C	504
#define	ID_BOOT_D	505
#define	ID_HDD_SIZE	506
#define	ID_WAITONERR	507
#define	ID_USESCANCODES	508
#define	ID_KEY_BE	509
#define	ID_KEY_BR	510
#define	ID_KEY_CF	511
#define	ID_KEY_DK	512
#define	ID_KEY_LA	513
#define	ID_KEY_PO	514
#define	ID_KEY_SF	515
#define	ID_KEY_SG	516
#define	ID_KEY_UK	517
#define	ID_KEY_US	518
#define	ID_KEY_YU	519
#define	ID_KEY_FO	520
#define	ID_KEY_MK	521
#define	ID_KEY_MT	522
#define	ID_KEY_PH	523
#define	ID_KEY_RO	524
#define	ID_KEY_SQ	525
#define	ID_KEY_TM	526
#define	ID_KEY_TR	527
#define	ID_KEY_UX	528
#define	ID_KEY_YC	529
#define	ID_KEY_DV	530
#define	ID_KEY_RH	531
#define	ID_KEY_LH	532
#define	ID_SAVESTATE_1	533
#define	ID_SAVESTATE_2	534
#define	ID_SAVESTATE_3	535
#define	ID_SAVESTATE_4	536
#define	ID_SAVESTATE_5	537
#define	ID_SAVESTATE_6	538
#define	ID_SAVESTATE_7	539
#define	ID_SAVESTATE_8	540
#define	ID_SAVESTATE_9	541
#define	ID_SAVESTATE_10	542
#define	ID_LOADSTATE_1	543
#define	ID_LOADSTATE_2	544
#define	ID_LOADSTATE_3	545
#define	ID_LOADSTATE_4	546
#define	ID_LOADSTATE_5	547
#define	ID_LOADSTATE_6	548
#define	ID_LOADSTATE_7	549
#define	ID_LOADSTATE_8	550
#define	ID_LOADSTATE_9	551
#define	ID_LOADSTATE_10	552
#define	ID_AUTOEXEC	553
#define	ID_SAVELANG	554
#define	ID_PRINTER_SECTION	555
#define	ID_MIDI_MT32_REVERBMODE_AUTO	556
#define	ID_MIDI_MT32_REVERBMODE_0	557
#define	ID_MIDI_MT32_REVERBMODE_1	558
#define	ID_MIDI_MT32_REVERBMODE_2	559
#define	ID_MIDI_MT32_REVERBMODE_3	560
#define	ID_MIDI_MT32_REVERBTIME_0	561
#define	ID_MIDI_MT32_REVERBTIME_1	562
#define	ID_MIDI_MT32_REVERBTIME_2	563
#define	ID_MIDI_MT32_REVERBTIME_3	564
#define	ID_MIDI_MT32_REVERBTIME_4	565
#define	ID_MIDI_MT32_REVERBTIME_5	566
#define	ID_MIDI_MT32_REVERBTIME_6	567
#define	ID_MIDI_MT32_REVERBTIME_7	568
#define	ID_MIDI_MT32_REVERBLEV_0	569
#define	ID_MIDI_MT32_REVERBLEV_1	570
#define	ID_MIDI_MT32_REVERBLEV_2	571
#define	ID_MIDI_MT32_REVERBLEV_3	572
#define	ID_MIDI_MT32_REVERBLEV_4	573
#define	ID_MIDI_MT32_REVERBLEV_5	574
#define	ID_MIDI_MT32_REVERBLEV_6	575
#define	ID_MIDI_MT32_REVERBLEV_7	576
#define	ID_RESTART	577
#define	ID_GLIDE_TRUE	578
#define	ID_GLIDE_EMU	579
#define	ID_SB_HW210	580
#define	ID_SB_HW220	581
#define	ID_SB_HW230	582
#define	ID_SB_HW240	583
#define	ID_SB_HW250	584
#define	ID_SB_HW260	585
#define	ID_SB_HW280	586
#define	ID_SB_OPL_HARDWARE	587
#define	ID_SB_OPL_HARDWAREGB	588
#define	ID_MIDI_MT32_49716	589
#define	ID_MIDI_MT32_48000	590
#define	ID_MIDI_MT32_32000	591
#define	ID_MIDI_MT32_16000	592
#define	ID_MIDI_MT32_8000	593
#define	ID_REMOVE_STATE_1	594
#define	ID_REMOVE_STATE_2	595
#define	ID_REMOVE_STATE_3	596
#define	ID_REMOVE_STATE_4	597
#define	ID_REMOVE_STATE_5	598
#define	ID_REMOVE_STATE_6	599
#define	ID_REMOVE_STATE_7	600
#define	ID_REMOVE_STATE_8	601
#define	ID_REMOVE_STATE_9	602
#define	ID_REMOVE_STATE_10	603
#define	ID_REMOVE_STATE_ALL	604
#define	ID_CHAR9	606
#define	ID_MULTISCAN	607
#define	ID_CPU_ADVANCED	608
#define	ID_DOS_ADVANCED	609
#define	ID_MIDI_SYNTH	610
#define	ID_MIDI_TIMIDITY	611
#define	ID_PS1_ON	612
#define	ID_PS1_OFF	613
#define	ID_PS1_49716	614
#define	ID_PS1_48000	615
#define	ID_PS1_44100	616
#define	ID_PS1_32000	617
#define	ID_PS1_22050	618
#define	ID_PS1_16000	619
#define	ID_PS1_11025	620
#define	ID_PS1_8000	621
#define	ID_MIDI_ADVANCED	622
#define	ID_MOUSE_VERTICAL	623
#define	ID_MIDI_MT32_DAC_AUTO	624
#define	ID_MIDI_MT32_DAC_0	625
#define	ID_MIDI_MT32_DAC_1	626
#define	ID_MIDI_MT32_DAC_2	627
#define	ID_MIDI_MT32_DAC_3	628
#define	ID_MIDI_MT32_REVERSESTEREO_TRUE	629
#define	ID_MIDI_MT32_REVERSESTEREO_FALSE	630
#define	ID_OVERSCAN_0	631
#define	ID_OVERSCAN_1	632
#define	ID_OVERSCAN_2	633
#define	ID_OVERSCAN_3	634
#define	ID_OVERSCAN_4	635
#define	ID_OVERSCAN_5	636
#define	ID_OVERSCAN_6	637
#define	ID_OVERSCAN_7	638
#define	ID_OVERSCAN_8	639
#define	ID_OVERSCAN_9	640
#define	ID_OVERSCAN_10	641
#define	ID_CPUTYPE_PENTIUM_MMX	645
#define	ID_SB_SB16VIBRA	646
#define	ID_MUTE	647
#define	ID_SWAPSTEREO	648
#define	ID_SEND_CTRL_ESC	649
#define	ID_SEND_ALT_TAB	650
#define	ID_SEND_CTRL_ALT_DEL	651
#define	ID_AUTOMOUNT_Z	652
#define	ID_MOUNT_LOCAL_Z	653
#define	ID_MOUNT_CDROM_Z	654
#define	ID_MOUNT_FLOPPY_Z	655
#define	ID_MOUNT_IMAGE_Z	656
#define	ID_BOOT_A_MOUNTED	657
#define	ID_BOOT_C_MOUNTED	658
#define	ID_BOOT_D_MOUNTED	659
#define	ID_XBRZ	660
#define	ID_NORMAL4X	661
#define	ID_NORMAL5X	662
#define	ID_HARDWARE_NONE	663
#define	ID_HARDWARE4X	664
#define	ID_HARDWARE5X	665
#define	ID_CPU_TURBO	666
#define	ID_SKIP_0 667
#define	ID_SKIP_1	668
#define	ID_SKIP_2	669
#define	ID_SKIP_3	670
#define	ID_SKIP_4	671
#define	ID_SKIP_5	672
#define	ID_SKIP_6	673
#define	ID_SKIP_7	674
#define	ID_SKIP_8	675
#define	ID_SKIP_9	676
#define	ID_SKIP_10 677
#define	ID_RATE_1_DELAY_1	678
#define	ID_RATE_2_DELAY_1	679
#define	ID_RATE_3_DELAY_1	680
#define	ID_RATE_4_DELAY_1	681
#define	ID_RATE_5_DELAY_1	682
#define	ID_RATE_6_DELAY_1	683
#define	ID_RATE_7_DELAY_1	684
#define	ID_RATE_8_DELAY_1	685
#define	ID_RATE_9_DELAY_1	686
#define	ID_RATE_10_DELAY_1	687
#define	ID_RATE_11_DELAY_1	688
#define	ID_RATE_12_DELAY_1	689
#define	ID_RATE_13_DELAY_1	690
#define	ID_RATE_14_DELAY_1	691
#define	ID_RATE_15_DELAY_1	692
#define	ID_RATE_16_DELAY_1	693
#define	ID_RATE_17_DELAY_1	694
#define	ID_RATE_18_DELAY_1	695
#define	ID_RATE_19_DELAY_1	696
#define	ID_RATE_20_DELAY_1	697
#define	ID_RATE_21_DELAY_1	698
#define	ID_RATE_22_DELAY_1	699
#define	ID_RATE_23_DELAY_1	700
#define	ID_RATE_24_DELAY_1	701
#define	ID_RATE_25_DELAY_1	702
#define	ID_RATE_26_DELAY_1	703
#define	ID_RATE_27_DELAY_1	704
#define	ID_RATE_28_DELAY_1	705
#define	ID_RATE_29_DELAY_1	706
#define	ID_RATE_30_DELAY_1	707
#define	ID_RATE_31_DELAY_1	708
#define	ID_RATE_32_DELAY_1	709
#define	ID_RATE_1_DELAY_2	710
#define	ID_RATE_2_DELAY_2	711
#define	ID_RATE_3_DELAY_2	712
#define	ID_RATE_4_DELAY_2	713
#define	ID_RATE_5_DELAY_2	714
#define	ID_RATE_6_DELAY_2	715
#define	ID_RATE_7_DELAY_2	716
#define	ID_RATE_8_DELAY_2	717
#define	ID_RATE_9_DELAY_2	718
#define	ID_RATE_10_DELAY_2	719
#define	ID_RATE_11_DELAY_2	720
#define	ID_RATE_12_DELAY_2	721
#define	ID_RATE_13_DELAY_2	722
#define	ID_RATE_14_DELAY_2	723
#define	ID_RATE_15_DELAY_2	724
#define	ID_RATE_16_DELAY_2	725
#define	ID_RATE_17_DELAY_2	726
#define	ID_RATE_18_DELAY_2	727
#define	ID_RATE_19_DELAY_2	728
#define	ID_RATE_20_DELAY_2	729
#define	ID_RATE_21_DELAY_2	730
#define	ID_RATE_22_DELAY_2	731
#define	ID_RATE_23_DELAY_2	732
#define	ID_RATE_24_DELAY_2	733
#define	ID_RATE_25_DELAY_2	734
#define	ID_RATE_26_DELAY_2	735
#define	ID_RATE_27_DELAY_2	736
#define	ID_RATE_28_DELAY_2	737
#define	ID_RATE_29_DELAY_2	738
#define	ID_RATE_30_DELAY_2	739
#define	ID_RATE_31_DELAY_2	740
#define	ID_RATE_32_DELAY_2	741
#define	ID_RATE_1_DELAY_3	742
#define	ID_RATE_2_DELAY_3	743
#define	ID_RATE_3_DELAY_3	744
#define	ID_RATE_4_DELAY_3	745
#define	ID_RATE_5_DELAY_3	746
#define	ID_RATE_6_DELAY_3	747
#define	ID_RATE_7_DELAY_3	748
#define	ID_RATE_8_DELAY_3	749
#define	ID_RATE_9_DELAY_3	750
#define	ID_RATE_10_DELAY_3	751
#define	ID_RATE_11_DELAY_3	752
#define	ID_RATE_12_DELAY_3	753
#define	ID_RATE_13_DELAY_3	754
#define	ID_RATE_14_DELAY_3	755
#define	ID_RATE_15_DELAY_3	756
#define	ID_RATE_16_DELAY_3	757
#define	ID_RATE_17_DELAY_3	758
#define	ID_RATE_18_DELAY_3	759
#define	ID_RATE_19_DELAY_3	760
#define	ID_RATE_20_DELAY_3	761
#define	ID_RATE_21_DELAY_3	762
#define	ID_RATE_22_DELAY_3	763
#define	ID_RATE_23_DELAY_3	764
#define	ID_RATE_24_DELAY_3	765
#define	ID_RATE_25_DELAY_3	766
#define	ID_RATE_26_DELAY_3	767
#define	ID_RATE_27_DELAY_3	768
#define	ID_RATE_28_DELAY_3	769
#define	ID_RATE_29_DELAY_3	770
#define	ID_RATE_30_DELAY_3	771
#define	ID_RATE_31_DELAY_3	772
#define	ID_RATE_32_DELAY_3	773
#define	ID_RATE_1_DELAY_4	774
#define	ID_RATE_2_DELAY_4	775
#define	ID_RATE_3_DELAY_4	776
#define	ID_RATE_4_DELAY_4	777
#define	ID_RATE_5_DELAY_4	778
#define	ID_RATE_6_DELAY_4	779
#define	ID_RATE_7_DELAY_4	780
#define	ID_RATE_8_DELAY_4	781
#define	ID_RATE_9_DELAY_4	782
#define	ID_RATE_10_DELAY_4	783
#define	ID_RATE_11_DELAY_4	784
#define	ID_RATE_12_DELAY_4	785
#define	ID_RATE_13_DELAY_4	786
#define	ID_RATE_14_DELAY_4	787
#define	ID_RATE_15_DELAY_4	788
#define	ID_RATE_16_DELAY_4	789
#define	ID_RATE_17_DELAY_4	790
#define	ID_RATE_18_DELAY_4	791
#define	ID_RATE_19_DELAY_4	792
#define	ID_RATE_20_DELAY_4	793
#define	ID_RATE_21_DELAY_4	794
#define	ID_RATE_22_DELAY_4	795
#define	ID_RATE_23_DELAY_4	796
#define	ID_RATE_24_DELAY_4	797
#define	ID_RATE_25_DELAY_4	798
#define	ID_RATE_26_DELAY_4	799
#define	ID_RATE_27_DELAY_4	800
#define	ID_RATE_28_DELAY_4	801
#define	ID_RATE_29_DELAY_4	802
#define	ID_RATE_30_DELAY_4	803
#define	ID_RATE_31_DELAY_4	804
#define	ID_RATE_32_DELAY_4	805
#define	ID_MOUSE_SENSITIVITY 806
#define	ID_AUTOMOUNT	807
#define	ID_GLIDE_LFB_FULL	808
#define	ID_GLIDE_LFB_FULL_NOAUX	809
#define	ID_GLIDE_LFB_READ	810
#define	ID_GLIDE_LFB_READ_NOAUX	811
#define	ID_GLIDE_LFB_WRITE	812
#define	ID_GLIDE_LFB_WRITE_NOAUX	813
#define	ID_GLIDE_LFB_NONE	814
#define	ID_GLIDE_SPLASH	815
#define	ID_GLIDE_EMU_FALSE	816
#define	ID_GLIDE_EMU_SOFTWARE	817
#define	ID_GLIDE_EMU_OPENGL	818
#define	ID_GLIDE_EMU_AUTO	819
#define	ID_ALWAYS_ON_TOP 820
#define ID_RESET_RESCALE 821
#define ID_RESET 822
#define ID_MTWAVE 823
#define ID_RESTART_DOS 824
#define ID_PC98_GDC5MHZ 825
#define ID_PC98_200SCANLINEEFFECT 826
#define ID_PC98_FOURPARTITIONSGRAPHICS 827
#define ID_PC98_4MHZ_TIMER 828
#define ID_PC98_5MHZ_TIMER 829
#define ID_PC98_CLEAR_TEXT_LAYER 830
#define ID_PC98_CLEAR_GRAPHICS_LAYER 831
#define ID_CPUTYPE_8086 832
#define ID_CPUTYPE_8086_PREFETCH 833
#define ID_CPUTYPE_80186 834
#define ID_CPUTYPE_80186_PREFETCH 835
#define ID_CPUTYPE_286 836
#define ID_CPUTYPE_286_PREFETCH 837
#define ID_CPUTYPE_486_PREFETCH 838
#define ID_CPUTYPE_PENTIUM_PRO 839
#define ID_SHOWCONSOLE 840
#define ID_PC98_ENABLEEGC 841
#define ID_PC98_ENABLEGRCG 842
#define ID_PC98_ENABLE16COLORS 843
#if defined(WIN32)
# define ID_WIN_SYSMENU_RESTOREMENU 0x0F00
# define ID_WIN_SYSMENU_TOGGLEMENU 0x0F01
# define ID_WIN_SYSMENU_MAPPER 0x0F02
# define ID_WIN_SYSMENU_CFG_GUI 0x0F03
# define ID_WIN_SYSMENU_PAUSE 0x0F04
# define ID_WIN_SYSMENU_RESETSIZE 0x0F05
#if defined(USE_TTF)
# define ID_WIN_SYSMENU_TTFINCSIZE 0x0F06
# define ID_WIN_SYSMENU_TTFDECSIZE 0x0F07
#endif
#endif
#define IDI_MAPPER 0x1000
#define IDI_CFG_GUI 0x1001
#define IDI_PAUSE 0x1002
